//进行axios的二次封装；使用请求和响应拦截器
import axios from 'axios'
import { ElMessage } from 'element-plus'

//利用axios.create()方法创建一个新的axios实例，可以配置一些其他的配置
let request = axios.create({
  // 基础路径
  baseURL: import.meta.env.VITE_APP_BASE_URL,
  // 超时时间
  timeout: 5000,
})

//添加请求与相应拦截器
request.interceptors.request.use(
  (config) => {
    // 在发送请求之前做些什么
    // 可以在这里添加token等信息
    //headers属性请求头，经常给服务器端携带公共参数
    //console.log(config)
    return config
  },
  (error) => {
    // 对请求错误做些什么
    return Promise.reject(error)
  },
)

//添加响应拦截器
request.interceptors.response.use(
  (response) => {
    // 对响应数据做点什么
    // 可以在这里处理响应数据
    // 简化数据
    //console.log(response)
    return response.data
  },
  (error) => {
    // 对响应错误做点什么
    // 可以在这里处理错误信息
    // 失败回调 处理HTTP网络错误
    // 定义一个变量，用来存储错误信息
    let message = ''
    let status = error.response.status
    switch (status) {
      case 401:
        message = 'Token已过期，请重新登录'
        break
      case 403:
        message = '没有权限访问'
        break
      case 404:
        message = '请求的资源不存在'
        break
      case 500:
        message = '服务器内部错误'
        break
      default:
        message = '网络异常，请稍后再试'
        break
    }
    //提示错误信息
    ElMessage({
      type: 'error',
      message: message,
    })
    return Promise.reject(error)
  },
)

//console.log(axios)
//console.log(request)

//对外暴露request实例
export default request
